Definitions

Struct Definitions 

pub struct Definitions(/* private fields */);

Implementations

Source

impl Definitions

pub fn new() -> Self

Methods from Deref<Target = RangeInclusiveMap<usize, DefinitionKind>>

pub fn iter(&self) -> Iter<'_, K, V>

Gets an iterator over all pairs of key range and value, ordered by key range.

The iterator element type is (&'a RangeInclusive<K>, &'a V).

pub fn get(&self, key: &K) -> Option<&V>

Returns a reference to the value corresponding to the given key, if the key is covered by any range in the map.

pub fn get_key_value(&self, key: &K) -> Option<(&RangeInclusive<K>, &V)>

Returns the range-value pair (as a pair of references) corresponding to the given key, if the key is covered by any range in the map.

pub fn contains_key(&self, key: &K) -> bool

Returns true if any range in the map covers the specified key.

pub fn clear(&mut self)

Clears the map, removing all elements.

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn insert(&mut self, range: RangeInclusive<K>, value: V)

Insert a pair of key range and value into the map.

If the inserted range partially or completely overlaps any existing range in the map, then the existing range (or ranges) will be partially or completely replaced by the inserted range.

If the inserted range either overlaps or is immediately adjacent any existing range mapping to the same value, then the ranges will be coalesced into a single contiguous range.

Panics

Panics if range start > end.

pub fn remove(&mut self, range: RangeInclusive<K>)

Removes a range from the map, if all or any of it was present.

If the range to be removed partially overlaps any ranges in the map, then those ranges will be contracted to no longer cover the removed range.

Panics

Panics if range start > end.

pub fn gaps<'a>( &'a self, outer_range: &'a RangeInclusive<K>, ) -> Gaps<'a, K, V, StepFnsT>

Gets an iterator over all the maximally-sized ranges contained in outer_range that are not covered by any range stored in the map.

The iterator element type is RangeInclusive<K>.

pub fn overlapping<R>(&self, range: R) -> Overlapping<'_, K, V, R>
where R: Borrow<RangeInclusive<K>>,

Gets an iterator over all the stored ranges that are either partially or completely overlapped by the given range.

pub fn overlaps(&self, range: &RangeInclusive<K>) -> bool

Returns true if any range in the map completely or partially overlaps the given range.

pub fn first_range_value(&self) -> Option<(&RangeInclusive<K>, &V)>

Returns the first range-value pair in this map, if one exists. The range in this pair is the minimum range in the map.

pub fn last_range_value(&self) -> Option<(&RangeInclusive<K>, &V)>

Returns the last range-value pair in this map, if one exists. The range in this pair is the maximum range in the map.